/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.detect;

import java.io.InputStream;

import org.xml.sax.ContentHandler;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;
import org.junit.Test;

import org.apache.tika.TikaTest;
import org.apache.tika.config.TikaConfig;
import org.apache.tika.exception.TikaException;
import org.apache.tika.io.TemporaryResources;
import org.apache.tika.io.TikaInputStream;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.mime.MediaType;
import org.apache.tika.parser.CompositeParser;
import org.apache.tika.parser.Parser;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.BodyContentHandler;


public class ConfiguredDetectorTest extends TikaTest {

    private void parseDocument(TikaConfig tikaConfig) throws Exception {
        Detector tikaDetector = tikaConfig.getDetector();
        Parser parser = new CompositeParser(
            tikaConfig.getMediaTypeRegistry(), tikaConfig.getParser());
        TemporaryResources tmp = new TemporaryResources();
        InputStream stream = getResourceAsStream("/test-documents/testPST.pst");
        stream = TikaInputStream.get(stream, tmp);
        ContentHandler handler = new BodyContentHandler();
        Metadata metadata = new Metadata();
        MediaType type = tikaDetector.detect(stream, metadata);
        metadata.set(Metadata.CONTENT_TYPE, type.toString());
        ParseContext context = new ParseContext();
        parser.parse(stream, handler, metadata, context);
        assertTrue(!handler.toString().isEmpty());
    }

    @Test
    public void testDefaultConfig() throws Exception {
        TikaConfig tikaConfig = TikaConfig.getDefaultConfig();
        parseDocument(tikaConfig);
    }

    @Test
    public void testLoadedDefaultConfig() throws Exception {
        String name = "/org/apache/tika/config/TIKA-1708-detector-default.xml";
        InputStream stream = getResourceAsStream(name);
        TikaConfig tikaConfig = new TikaConfig(stream);
        parseDocument(tikaConfig);
    }

    @Test
    public void testLoadedCompositeConfig() throws Exception {
        String name = "/org/apache/tika/config/TIKA-1708-detector-composite.xml";
        InputStream stream = getResourceAsStream(name);
        TikaConfig tikaConfig = new TikaConfig(stream);
        parseDocument(tikaConfig);
    }

}
